Author: Marina Guvakova

## TOP-LEVEL MENUBAR

NB. Here we present menu entries according to their layout on MacOS. On other platforms the layout can slightly differ.

Python

About

- g3mclass version

- license

- developers

Services

- services preferences

Hide g3mclass

Hide others

Show all

Quit g3mclass

File

- Open: open a data file

- Open example : open an example data file distributed with the software

- Save: save output

- Open parameters: open saved modeling parameters

- Save parameters: save current modeling parameters

Action

- learn model

- draw plots

- draw heatmaps

Help

Window

## MAIN TABS AND SUBTABS

Welcome

- general description of g3mclass appears first-time software is opened.

Data

- input data appear here once the data file is opened

Parameters

- adjustable set of controls for the models, plots and heatmaps parameters (for more info, see 'Parameters')

Model

- subtabs with the analyte names appear under main tab.

- each subtab contains information on model parameters ('par'), saved and organized in rows and columns ('row_col'). This includes the configuration variables learned with 'proba' classification

- 'row', class number for each Gaussian

- 'mean', the mean value for each Gaussian

- 'sd', standard deviation for each Gaussian

- 'a', weight for each Gaussian; the sum of all Gaussians is 1.0

- Bayesian information criterion (BIC)

- the log likelihood function (loglike)

- number of iterations (it)

- whether the maximum number of iterations has been reached (false/true).

- software calculated multi-cutoffs with the cutoff intervals for classes adjacent to class '0', i.e., class '-1' and class'1'.

- 'breaks', breaks between classes using 'cutoff classification'

- 'labels', class description using 'cutoff classification'

- 's. breaks', breaks between classes using 'stringent cutoff classification'

- 's. labels', class description using 'stringent cutoff classification'

- software records 'par_mod ', model setting parameters (for more info, see 'Parameters')

  - 'k', number of bins in a histogram

  - 'khlen', length of vector of k

  - 'k_var', variable or fixed k were used (false/true)

  - 'thr_di', threshold for fusing too close Gaussians

  - 'thr_w', threshold for vanishing Gaussians

- software records 'history', present only if 'k' was set to be varying. It represents a matrix with following columns

  - 'row_col', row number in the matrix

  - 'k', number of histogram bins 'k' used in a given run

  - 'BIC', Value of the BIC criterion obtained in a given run

  - 'classes', list of classes in GMM model obtained in a given run

- software records 'resample', present only if resampling was asked in 'Parameters' tab

  - 'fraction', real number between 0 and 1 giving the fraction of initial sample that was used in resampling

  - 'resampling_number', integer number indicating how many resamples were generated and used.

  - 'what', string 'ref' or 'test' or 'ref,test' indicating what samples were resampled.

  - 'stats', matrices with summary statistics calculated over new samples. They are calculated on 'class means' and 'thresholds'. Row and column names in these matrices are self-explanatory. For example, row 'count' indicates how many times a given parameter was estimated in all resamples; 'mean' is a mean value a given parameter etc.

- software records 'creator ', information

  - 'name', software name

  - 'version', software version

  - 'data', saved data directory

  - 'date', file creation date/time

Model Plots

- a total mixture model and GMM's components appear here once the data file is processed

Test class

- 'proba'>'cutoff'>'s.cutoff' output and summary statistics for test classification

- subtabs with the analyte names appear under the main tab.

Ref class

- 'proba'>'cutoff'>'s.cutoff' output and summary statistics for reference classification

- subtabs with the analyte names appear under the main tab.

Query class

- 'proba'>'cutoff'>'s.cutoff' output and summary statistics for query classification

- pulldown menu with the analyte and optional query names appears under the main tab.

Heatmaps

- a graphical representation of 'proba'>'cutoff'>'s.cutoff' classifications

- heatmap color codes: class'0' in shade of green, classes labeled with negative (e.g., -1, -2, etc.) and positive (e.g., 1, 2, etc.) integers in shades of blue and red, respectively. The bigger the absolute integer value the more intense the corresponding color shade is.